.. Test Repository documentation master file, created by
   sphinx-quickstart on Mon Dec  3 23:24:00 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

stestr
======

Contents:

.. toctree::
   :maxdepth: 2

   README
   MANUAL
   CONTRIBUTING
   developer_guidelines
   internal_arch
   api


Indices and tables
==================

* :ref:`genindex`

